summaryrefslogtreecommitdiff
path: root/gtk2_ardour/editor_drag.h
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2013-07-10 19:10:06 -0400
committerPaul Davis <paul@linuxaudiosystems.com>2013-07-10 19:10:06 -0400
commit525cb6b4a77e0127ebbb1b8e06d28711927b1633 (patch)
treebf05fc9787f30eb2eb26dc98d14747278a9d2d49 /gtk2_ardour/editor_drag.h
parent63e9138f1fccfa64b8e894fd18e8985e564cd904 (diff)
some sort-of-deep fixes to get autoscroll/vertical scroll to work properly for cairocanvas
Diffstat (limited to 'gtk2_ardour/editor_drag.h')
-rw-r--r--gtk2_ardour/editor_drag.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/gtk2_ardour/editor_drag.h b/gtk2_ardour/editor_drag.h
index df55270e54..3f4c82d2d0 100644
--- a/gtk2_ardour/editor_drag.h
+++ b/gtk2_ardour/editor_drag.h
@@ -74,12 +74,12 @@ public:
return !_drags.empty ();
}
/** @return current pointer x position in trackview coordinates */
double current_pointer_x () const {
return _current_pointer_x;
}
/** @return current pointer y position in trackview coordinates */
double current_pointer_y () const {
return _current_pointer_y;
}
@@ -93,8 +93,8 @@ private:
Editor* _editor;
std::list<Drag*> _drags;
bool _ending; ///< true if end_grab or abort is in progress, otherwise false
- double _current_pointer_x; ///< trackview x of the current pointer
- double _current_pointer_y; ///< trackview y of the current pointer
+ double _current_pointer_x; ///< canvas-coordinate space x of the current pointer
+ double _current_pointer_y; ///< canvas-coordinate space y of the current pointer
ARDOUR::framepos_t _current_pointer_frame; ///< frame that the pointer is now at
bool _old_follow_playhead; ///< state of Editor::follow_playhead() before the drags started
};
@@ -74,12 +74,12 @@ public:
return !_drags.empty ();
}
- /** @return current pointer x position in trackview coordinates */
+ /** @return current pointer x position in canvas coordinates */
double current_pointer_x () const {
return _current_pointer_x;
@@ -74,12 +74,12 @@ public:
return _current_pointer_x;
}
- /** @return current pointer y position in trackview coordinates */
+ /** @return current pointer y position in canvas coordinates */
double current_pointer_y () const {
return _current_pointer_y;